==============
 Installation
==============

Install the extension with one of the following commands::

    $ easy_install sigal

or alternatively if you have pip installed::

    $ pip install sigal

To install the development version, see the :doc:`contribute`.

Dependencies
~~~~~~~~~~~~

- Blinker
- Click
- Jinja2
- Pilkit
- Pillow
- Python Markdown

Packages
~~~~~~~~

- Archlinux: `AUR package <https://aur.archlinux.org/packages/sigal/>`_
